==> zio-aws-groundstation_3-5.17.130.7-sources.jar: zio/aws/groundstation/model/DeleteDataflowEndpointGroupRequest.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteDataflowEndpointGroupRequest(
    dataflowEndpointGroupId: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest = {
    import DeleteDataflowEndpointGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
      .builder()
      .dataflowEndpointGroupId(dataflowEndpointGroupId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest.ReadOnly =
    zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest
      .wrap(buildAwsValue())
}
object DeleteDataflowEndpointGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest =
      zio.aws.groundstation.model
        .DeleteDataflowEndpointGroupRequest(dataflowEndpointGroupId)
    def dataflowEndpointGroupId: String
    def getDataflowEndpointGroupId: ZIO[Any, Nothing, String] =
      ZIO.succeed(dataflowEndpointGroupId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
  ) extends zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest.ReadOnly {
    override val dataflowEndpointGroupId: String =
      impl.dataflowEndpointGroupId(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
  ): zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-groundstation_3-5.19.26.1-sources.jar: zio/aws/groundstation/model/DeleteDataflowEndpointGroupRequest.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteDataflowEndpointGroupRequest(
    dataflowEndpointGroupId: Uuid
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest = {
    import DeleteDataflowEndpointGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
      .builder()
      .dataflowEndpointGroupId(
        Uuid.unwrap(dataflowEndpointGroupId): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest.ReadOnly =
    zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest
      .wrap(buildAwsValue())
}
object DeleteDataflowEndpointGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest =
      zio.aws.groundstation.model
        .DeleteDataflowEndpointGroupRequest(dataflowEndpointGroupId)
    def dataflowEndpointGroupId: Uuid
    def getDataflowEndpointGroupId: ZIO[Any, Nothing, Uuid] =
      ZIO.succeed(dataflowEndpointGroupId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
  ) extends zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest.ReadOnly {
    override val dataflowEndpointGroupId: Uuid =
      zio.aws.groundstation.model.primitives
        .Uuid(impl.dataflowEndpointGroupId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteDataflowEndpointGroupRequest
  ): zio.aws.groundstation.model.DeleteDataflowEndpointGroupRequest.ReadOnly =
    new Wrapper(impl)
}
